@@ -61,6 +61,11 @@ void init_Url(iUrl *d, const iString *text) {
             d->host = capturedRange_RegExpMatch(&m, 3);
             d->port = capturedRange_RegExpMatch(&m, 7);
         }
+        /* Remove brackets from an IPv6 literal. */
+        if (size_Range(&d->host) > 2 && d->host.start[0] == '[' && d->host.end[-1] == ']') {
+            d->host.start++;
+            d->host.end--;
+        }
     }
 }
 
@@ -285,8 +290,16 @@ const iString *absoluteUrl_String(const iString *d, const iString *urlMaybeRelat
     appendCStr_String(absolute, "://");
     /* Authority. */ {
         const iUrl *selHost = isDef_(rel.host) ? &rel : &orig;
+        const iBool isIPv6 = size_Range(&selHost->host) > 0 &&
+                             iStrStrN(selHost->host.start, ":", size_Range(&selHost->host)) != NULL;
         iString *decHost = punyDecodeHost_(selHost->host);
+        if (isIPv6) {
+            appendCStr_String(absolute, "[");
+        }
         append_String(absolute, decHost);
+        if (isIPv6) {
+            appendCStr_String(absolute, "]");
+        }
         delete_String(decHost);
         /* Default Gemini port is removed as redundant; normalization. */
         if (!isEmpty_Range(&selHost->port) && (!equalCase_Rangecc(scheme, "gemini")
