@@ -35,17 +35,30 @@ void    setTextColor_LabelWidget    (iLabelWidget *, int color);
 void    setText_LabelWidget         (iLabelWidget *, const iString *text); /* resizes widget */
 void    setTextCStr_LabelWidget     (iLabelWidget *, const char *text);
 void    setCommand_LabelWidget      (iLabelWidget *, const iString *command);
+void    setIcon_LabelWidget         (iLabelWidget *, iChar icon);
 
+iBool   checkIcon_LabelWidget       (iLabelWidget *);
 void    updateSize_LabelWidget      (iLabelWidget *);
 void    updateText_LabelWidget      (iLabelWidget *, const iString *text); /* not resized */
 void    updateTextCStr_LabelWidget  (iLabelWidget *, const char *text); /* not resized */
 
-const iString *text_LabelWidget    (const iLabelWidget *);
-const iString *command_LabelWidget  (const iLabelWidget *);
+iInt2           defaultSize_LabelWidget (const iLabelWidget *);
+int             font_LabelWidget        (const iLabelWidget *);
+const iString * text_LabelWidget        (const iLabelWidget *);
+const iString * sourceText_LabelWidget  (const iLabelWidget *); /* untranslated */
+const iString * command_LabelWidget     (const iLabelWidget *);
+iChar           icon_LabelWidget        (const iLabelWidget *);
 
 iLabelWidget *newKeyMods_LabelWidget(const char *label, int key, int kmods, const char *command);
 iLabelWidget *newColor_LabelWidget  (const char *text, int color);
 
+iLocalDef iLabelWidget *newFont_LabelWidget(const char *label, const char *command, int fontId) {
+    iLabelWidget *d = new_LabelWidget(label, command);
+    checkIcon_LabelWidget(d);
+    setFont_LabelWidget(d, fontId);
+    return d;
+}
+
 iLocalDef iLabelWidget *newEmpty_LabelWidget(void) {
     return new_LabelWidget("", NULL);
 }
