@@ -23,9 +23,23 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. */
 #include "scrollwidget.h"
 #include "paint.h"
 #include "util.h"
+#include "periodic.h"
+#include "app.h"
+
+#include <SDL_timer.h>
 
 iDefineObjectConstruction(ScrollWidget)
 
+static float minOpacity_(void) {
+#if !defined (iPlatformApple)
+    if (deviceType_App() == desktop_AppDeviceType) {
+        /* Don't fade the scrollbars completely. */
+        return 0.333f;
+    }
+#endif
+    return 0.0f;
+}
+
 struct Impl_ScrollWidget {
     iWidget widget;
     iRangei range;
@@ -33,8 +47,23 @@ struct Impl_ScrollWidget {
     int thumbSize;
     iClick click;
     int startThumb;
+    iAnim opacity;
+    uint32_t fadeStart;
+    iBool willCheckFade;
 };
 
+static void updateMetrics_ScrollWidget_(iScrollWidget *d) {
+    as_Widget(d)->rect.size.x = gap_UI * 3;
+}
+
+static void animateOpacity_ScrollWidget_(void *ptr) {
+    iScrollWidget *d = ptr;
+    if (!isFinished_Anim(&d->opacity)) {
+        addTicker_App(animateOpacity_ScrollWidget_, ptr);
+    }
+    refresh_Widget(ptr);
+}
+
 void init_ScrollWidget(iScrollWidget *d) {
     iWidget *w = as_Widget(d);
     init_Widget(w);
@@ -43,12 +72,15 @@ void init_ScrollWidget(iScrollWidget *d) {
                     fixedWidth_WidgetFlag | resizeToParentHeight_WidgetFlag |
                         moveToParentRightEdge_WidgetFlag | touchDrag_WidgetFlag,
                     iTrue);
-    w->rect.size.x = gap_UI * 3;
+    updateMetrics_ScrollWidget_(d);
     init_Click(&d->click, d, SDL_BUTTON_LEFT);
+    init_Anim(&d->opacity, minOpacity_());
+    d->willCheckFade = iFalse;
 }
 
 void deinit_ScrollWidget(iScrollWidget *d) {
-    iUnused(d);
+    remove_Periodic(periodic_App(), d);
+    removeTicker_App(animateOpacity_ScrollWidget_, d);
 }
 
 static int thumbSize_ScrollWidget_(const iScrollWidget *d) {
@@ -70,8 +102,28 @@ static iRect thumbRect_ScrollWidget_(const iScrollWidget *d) {
     return rect;
 }
 
+static void unfade_ScrollWidget_(iScrollWidget *d, float opacity) {
+    d->fadeStart = SDL_GetTicks() + 1000;
+    if (targetValue_Anim(&d->opacity) < opacity) {
+        setValue_Anim(&d->opacity, opacity, 66);
+        addTicker_App(animateOpacity_ScrollWidget_, d);
+    }
+    if (!d->willCheckFade) {
+        d->willCheckFade = iTrue;
+        /* TODO: This causes an inexplicable refresh issue on macOS: the drawing of one frame
+           takes 100ms for some reason (not the current frame but some time after). */
+        add_Periodic(periodic_App(), d, "scrollbar.fade");
+    }
+    refresh_Widget(d);
+}
+
 static void checkVisible_ScrollWidget_(iScrollWidget *d) {
-    setFlags_Widget(as_Widget(d), hidden_WidgetFlag, height_Rect(thumbRect_ScrollWidget_(d)) == 0);
+    const iBool wasHidden = !isVisible_Widget(d);
+    const iBool isHidden = d->thumbSize != 0 ? height_Rect(thumbRect_ScrollWidget_(d)) == 0 : iTrue;
+    setFlags_Widget(as_Widget(d), hidden_WidgetFlag, isHidden);
+    if (wasHidden && !isHidden) {
+        unfade_ScrollWidget_(d, 1.0f);
+    }
 }
 
 void setRange_ScrollWidget(iScrollWidget *d, iRangei range) {
@@ -81,13 +133,39 @@ void setRange_ScrollWidget(iScrollWidget *d, iRangei range) {
 }
 
 void setThumb_ScrollWidget(iScrollWidget *d, int thumb, int thumbSize) {
+    const int oldThumb = d->thumb;
     d->thumb     = thumb;
     d->thumbSize = thumbSize;
     checkVisible_ScrollWidget_(d);
+    if (oldThumb != d->thumb && thumbSize) {
+        unfade_ScrollWidget_(d, 1.0f);
+    }
 }
 
 static iBool processEvent_ScrollWidget_(iScrollWidget *d, const SDL_Event *ev) {
     iWidget *w = as_Widget(d);
+    if (isMetricsChange_UserEvent(ev)) {
+        updateMetrics_ScrollWidget_(d);
+    }
+    if (ev->type == SDL_MOUSEMOTION) {
+        const iInt2 mouse = init_I2(ev->motion.x, ev->motion.y);
+        const iBool isNearby = containsExpanded_Widget(&d->widget, mouse, 4 * gap_UI);
+        const iBool isOver = isNearby && contains_Rect(thumbRect_ScrollWidget_(d), mouse);
+        if (isNearby) {
+            unfade_ScrollWidget_(d, isOver ? 1.0f : 0.4f);
+        }
+    }
+    if (isCommand_UserEvent(ev, "scrollbar.fade")) {
+        if (d->willCheckFade && SDL_GetTicks() > d->fadeStart) {
+            setValue_Anim(&d->opacity, minOpacity_(), 200);
+            remove_Periodic(periodic_App(), d);
+            d->willCheckFade = iFalse;
+            if (!isFinished_Anim(&d->opacity)) {
+                addTicker_App(animateOpacity_ScrollWidget_, d);
+            }
+        }
+        return iFalse;
+    }
     switch (processEvent_Click(&d->click, ev)) {
         case started_ClickResult:
             setFlags_Widget(w, pressed_WidgetFlag, iTrue);
@@ -137,10 +215,18 @@ static void draw_ScrollWidget_(const iScrollWidget *d) {
     if (bounds.size.x > 0) {
         iPaint p;
         init_Paint(&p);
-        //drawVLine_Paint(&p, topLeft_Rect(bounds), height_Rect(bounds), uiSeparator_ColorId);
+        /* Blend if opacity is not at maximum. */
+        p.alpha = 255 * value_Anim(&d->opacity);
+        SDL_Renderer *render = renderer_Window(get_Window());
+        if (p.alpha < 255) {
+            SDL_SetRenderDrawBlendMode(render, SDL_BLENDMODE_BLEND);
+        }
         const iRect thumbRect = shrunk_Rect(
             thumbRect_ScrollWidget_(d), init_I2(isPressed ? gap_UI : (gap_UI * 4 / 3), gap_UI / 2));
         fillRect_Paint(&p, thumbRect, isPressed ? uiBackgroundPressed_ColorId : tmQuote_ColorId);
+        if (p.alpha < 255) {
+            SDL_SetRenderDrawBlendMode(render, SDL_BLENDMODE_NONE);
+        }
     }
 }
 
